This demo enables participants to experience the teleoperation of a robotic arm under various extraterrestrial conditions.

While performing a task, participants can opt-in for **collection of the demonstrated trajectories** to contribute towards a training dataset usable for **Imitation Learning**, **Offline Reinforcement Learning**, and other related areas of **Robot Learning** research focused on contact-rich manipulation in space.

The simulation environments are built on top of **NVIDIA Isaac Sim**, and this graphical interface is developed using **egui**. Most communication among the components is facilitated using **ROS 2** while employing its C++ (rclcpp), Python (rclpy), and Rust (r2r) client libraries for the different components.

The demo is developed by **Andrej Orsula**.
